@@ -1,15 +1,15 @@
-
 #' Connected components of a graph
 #'
 #' @description
 #' `r lifecycle::badge("deprecated")`
 #'
-#' `no.clusters()` was renamed to `count_components()` to create a more
+#' `no.clusters()` was renamed to [count_components()] to create a more
 #' consistent API.
 #' @inheritParams count_components
 #' @keywords internal
 #' @export
-no.clusters <- function(graph, mode = c("weak", "strong")) { # nocov start
+no.clusters <- function(graph, mode = c("weak", "strong")) {
+  # nocov start
   lifecycle::deprecate_soft("2.0.0", "no.clusters()", "count_components()")
   count_components(graph = graph, mode = mode)
 } # nocov end
@@ -19,14 +19,25 @@ no.clusters <- function(graph, mode = c("weak", "strong")) { # nocov start
 #' @description
 #' `r lifecycle::badge("deprecated")`
 #'
-#' `decompose.graph()` was renamed to `decompose()` to create a more
+#' `decompose.graph()` was renamed to [decompose()] to create a more
 #' consistent API.
 #' @inheritParams decompose
 #' @keywords internal
 #' @export
-decompose.graph <- function(graph, mode = c("weak", "strong"), max.comps = NA, min.vertices = 0) { # nocov start
+decompose.graph <- function(
+  graph,
+  mode = c("weak", "strong"),
+  max.comps = NA,
+  min.vertices = 0
+) {
+  # nocov start
   lifecycle::deprecate_soft("2.0.0", "decompose.graph()", "decompose()")
-  decompose(graph = graph, mode = mode, max.comps = max.comps, min.vertices = min.vertices)
+  decompose(
+    graph = graph,
+    mode = mode,
+    max.comps = max.comps,
+    min.vertices = min.vertices
+  )
 } # nocov end
 
 #' Connected components of a graph
@@ -34,14 +45,29 @@ decompose.graph <- function(graph, mode = c("weak", "strong"), max.comps = NA, m
 #' @description
 #' `r lifecycle::badge("deprecated")`
 #'
-#' `cluster.distribution()` was renamed to `component_distribution()` to create a more
+#' `cluster.distribution()` was renamed to [component_distribution()] to create a more
 #' consistent API.
 #' @inheritParams component_distribution
 #' @keywords internal
 #' @export
-cluster.distribution <- function(graph, cumulative = FALSE, mul.size = FALSE, ...) { # nocov start
-  lifecycle::deprecate_soft("2.0.0", "cluster.distribution()", "component_distribution()")
-  component_distribution(graph = graph, cumulative = cumulative, mul.size = mul.size, ...)
+cluster.distribution <- function(
+  graph,
+  cumulative = FALSE,
+  mul.size = FALSE,
+  ...
+) {
+  # nocov start
+  lifecycle::deprecate_soft(
+    "2.0.0",
+    "cluster.distribution()",
+    "component_distribution()"
+  )
+  component_distribution(
+    graph = graph,
+    cumulative = cumulative,
+    mul.size = mul.size,
+    ...
+  )
 } # nocov end
 
 #' Biconnected components
@@ -49,13 +75,18 @@ cluster.distribution <- function(graph, cumulative = FALSE, mul.size = FALSE, ..
 #' @description
 #' `r lifecycle::badge("deprecated")`
 #'
-#' `biconnected.components()` was renamed to `biconnected_components()` to create a more
+#' `biconnected.components()` was renamed to [biconnected_components()] to create a more
 #' consistent API.
 #' @inheritParams biconnected_components
 #' @keywords internal
 #' @export
-biconnected.components <- function(graph) { # nocov start
-  lifecycle::deprecate_soft("2.0.0", "biconnected.components()", "biconnected_components()")
+biconnected.components <- function(graph) {
+  # nocov start
+  lifecycle::deprecate_soft(
+    "2.0.0",
+    "biconnected.components()",
+    "biconnected_components()"
+  )
   biconnected_components(graph = graph)
 } # nocov end
 
@@ -64,13 +95,18 @@ biconnected.components <- function(graph) { # nocov start
 #' @description
 #' `r lifecycle::badge("deprecated")`
 #'
-#' `articulation.points()` was renamed to `articulation_points()` to create a more
+#' `articulation.points()` was renamed to [articulation_points()] to create a more
 #' consistent API.
 #' @inheritParams articulation_points
 #' @keywords internal
 #' @export
-articulation.points <- function(graph) { # nocov start
-  lifecycle::deprecate_soft("2.0.0", "articulation.points()", "articulation_points()")
+articulation.points <- function(graph) {
+  # nocov start
+  lifecycle::deprecate_soft(
+    "2.0.0",
+    "articulation.points()",
+    "articulation_points()"
+  )
   articulation_points(graph = graph)
 } # nocov end
 #   IGraph R package
@@ -106,8 +142,12 @@ articulation.points <- function(graph) { # nocov start
 #' @family components
 #' @export
 #' @importFrom graphics hist
-component_distribution <- function(graph, cumulative = FALSE, mul.size = FALSE,
-                                   ...) {
+component_distribution <- function(
+  graph,
+  cumulative = FALSE,
+  mul.size = FALSE,
+  ...
+) {
   ensure_igraph(graph)
 
   cs <- components(graph, ...)$csize
@@ -126,7 +166,6 @@ component_distribution <- function(graph, cumulative = FALSE, mul.size = FALSE,
 }
 
 
-
 #' Decompose a graph into components
 #'
 #' Creates a separate graph for each connected component of a graph.
@@ -157,22 +196,26 @@ component_distribution <- function(graph, cumulative = FALSE, mul.size = FALSE,
 #' components <- decompose(g, min.vertices = 2)
 #' sapply(components, diameter)
 #'
-decompose <- function(graph, mode = c("weak", "strong"), max.comps = NA,
-                      min.vertices = 0) {
+decompose <- function(
+  graph,
+  mode = c("weak", "strong"),
+  max.comps = NA,
+  min.vertices = 0
+) {
   ensure_igraph(graph)
   mode <- igraph.match.arg(mode)
-  mode <- switch(mode,
-    "weak" = 1L,
-    "strong" = 2L
-  )
+  mode <- switch(mode, "weak" = 1L, "strong" = 2L)
 
   if (is.na(max.comps)) {
     max.comps <- -1
   }
   on.exit(.Call(R_igraph_finalizer))
   .Call(
-    R_igraph_decompose, graph, as.numeric(mode),
-    as.numeric(max.comps), as.numeric(min.vertices)
+    R_igraph_decompose,
+    graph,
+    as.numeric(mode),
+    as.numeric(max.comps),
+    as.numeric(min.vertices)
   )
 }
 
@@ -213,10 +256,12 @@ decompose <- function(graph, mode = c("weak", "strong"), max.comps = NA,
 #'
 #' @family components
 #' @export
+#' @cdocs igraph_articulation_points
 articulation_points <- articulation_points_impl
 
 #' @rdname articulation_points
 #' @export
+#' @cdocs igraph_bridges
 bridges <- bridges_impl
 
 
@@ -235,15 +280,26 @@ bridges <- bridges_impl
 #'
 #' @param graph The input graph. It is treated as an undirected graph, even if
 #'   it is directed.
-#' @return A named list with three components: \item{no}{Numeric scalar, an
-#'   integer giving the number of biconnected components in the graph.}
-#'   \item{tree_edges}{The components themselves, a list of numeric vectors. Each
-#'   vector is a set of edge ids giving the edges in a biconnected component.
-#'   These edges define a spanning tree of the component.}
-#'   \item{component_edges}{A list of numeric vectors. It gives all edges in the
-#'   components.} \item{components}{A list of numeric vectors, the vertices of
-#'   the components.} \item{articulation_points}{The articulation points of the
-#'   graph. See [articulation_points()].}
+#' @return A named list with three components:
+#'   \describe{
+#'     \item{no}{
+#'       Numeric scalar, an integer giving the number of biconnected components in the graph.
+#'     }
+#'     \item{tree_edges}{
+#'       The components themselves, a list of numeric vectors.
+#'       Each vector is a set of edge ids giving the edges in a biconnected component.
+#'       These edges define a spanning tree of the component.
+#'     }
+#'     \item{component_edges}{
+#'       A list of numeric vectors. It gives all edges in the components.
+#'     }
+#'     \item{components}{
+#'       A list of numeric vectors, the vertices of the components.
+#'     }
+#'     \item{articulation_points}{
+#'       The articulation points of the graph. See [articulation_points()].
+#'     }
+#'   }
 #' @author Gabor Csardi \email{csardi.gabor@@gmail.com}
 #' @seealso [articulation_points()], [components()],
 #' [is_connected()], [vertex_connectivity()]
@@ -256,6 +312,7 @@ bridges <- bridges_impl
 #' bc <- biconnected_components(g)
 #' @family components
 #' @export
+#' @cdocs igraph_biconnected_components
 biconnected_components <- function(graph) {
   # Function call
   res <- biconnected_components_impl(graph)
@@ -264,16 +321,31 @@ biconnected_components <- function(graph) {
   # See https://github.com/igraph/rigraph/issues/1203
 
   if (igraph_opt("return.vs.es")) {
-    res$tree_edges <- lapply(res$tree_edges, unsafe_create_es, graph = graph, es = E(graph))
+    res$tree_edges <- lapply(
+      res$tree_edges,
+      unsafe_create_es,
+      graph = graph,
+      es = E(graph)
+    )
     res$tree.edges <- NULL
   }
 
   if (igraph_opt("return.vs.es")) {
-    res$component_edges <- lapply(res$component_edges, unsafe_create_es, graph = graph, es = E(graph))
+    res$component_edges <- lapply(
+      res$component_edges,
+      unsafe_create_es,
+      graph = graph,
+      es = E(graph)
+    )
     res$component.edges <- NULL
   }
   if (igraph_opt("return.vs.es")) {
-    res$components <- lapply(res$components, unsafe_create_vs, graph = graph, verts = V(graph))
+    res$components <- lapply(
+      res$components,
+      unsafe_create_vs,
+      graph = graph,
+      verts = V(graph)
+    )
   }
   if (igraph_opt("return.vs.es")) {
     res$articulation_points <- create_vs(graph, res$articulation_points)
@@ -310,15 +382,14 @@ biconnected_components <- function(graph) {
 #' is_biconnected(make_full_graph(2))
 #' @family components
 #' @export
+#' @cdocs igraph_is_biconnected
 is_biconnected <- is_biconnected_impl
 
 
 #' @rdname components
 #' @export
 largest_component <- function(graph, mode = c("weak", "strong")) {
-  if (!is_igraph(graph)) {
-    stop("Not a graph object")
-  }
+  ensure_igraph(graph)
 
   comps <- components(graph, mode = mode)
 
