@@ -1,3 +1,23 @@
+#' Minimum spanning tree
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `minimum.spanning.tree()` was renamed to [mst()] to create a more
+#' consistent API.
+#' @inheritParams mst
+#' @keywords internal
+#' @export
+minimum.spanning.tree <- function(
+  graph,
+  weights = NULL,
+  algorithm = NULL,
+  ...
+) {
+  # nocov start
+  lifecycle::deprecate_soft("2.0.0", "minimum.spanning.tree()", "mst()")
+  mst(graph = graph, weights = weights, algorithm = algorithm, ...)
+} # nocov end
 #   IGraph R package
 #   Copyright (C) 2005-2012  Gabor Csardi <csardi.gabor@gmail.com>
 #   334 Harvard street, Cambridge, MA 02139 USA
@@ -19,8 +39,6 @@
 #
 ###################################################################
 
-
-
 #' Minimum spanning tree
 #'
 #' A *spanning tree* of a connected graph is a connected subgraph with
@@ -33,7 +51,6 @@
 #'
 #' If the graph is not connected a minimum spanning forest is returned.
 #'
-#' @aliases minimum.spanning.tree
 #' @param graph The graph object to analyze.
 #' @param weights Numeric vector giving the weights of the edges in the
 #'   graph. The order is determined by the edge ids. This is ignored if the
@@ -62,11 +79,8 @@
 #' g <- sample_gnp(100, 3 / 100)
 #' g_mst <- mst(g)
 #'
-mst <- function(graph, weights = NULL,
-                algorithm = NULL, ...) {
-  if (!is_igraph(graph)) {
-    stop("Not a graph object")
-  }
+mst <- function(graph, weights = NULL, algorithm = NULL, ...) {
+  ensure_igraph(graph)
 
   if (is.null(algorithm)) {
     if (!is.null(weights) || "weight" %in% edge_attr_names(graph)) {
@@ -81,13 +95,13 @@ mst <- function(graph, weights = NULL,
     .Call(R_igraph_minimum_spanning_tree_unweighted, graph)
   } else if (algorithm == "prim") {
     if (is.null(weights) && !"weight" %in% edge_attr_names(graph)) {
-      stop("edges weights must be supplied for Prim's algorithm")
+      cli::cli_abort("edges weights must be supplied for Prim's algorithm.")
     } else if (is.null(weights)) {
       weights <- E(graph)$weight
     }
     on.exit(.Call(R_igraph_finalizer))
     .Call(R_igraph_minimum_spanning_tree_prim, graph, as.numeric(weights))
   } else {
-    stop("Invalid algorithm")
+    cli::cli_abort("Invalid {.arg algorithm}.")
   }
 }
