@@ -1,3 +1,39 @@
+#' Parameters for the igraph package
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `igraph.options()` was renamed to [igraph_options()] to create a more
+#' consistent API.
+#' @inheritParams igraph_options
+#' @keywords internal
+#' @export
+igraph.options <- function(...) {
+  # nocov start
+  lifecycle::deprecate_soft("2.0.0", "igraph.options()", "igraph_options()")
+  igraph_i_options(...)
+} # nocov end
+
+#' Parameters for the igraph package
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `getIgraphOpt()` was renamed to [igraph_opt()] to create a more
+#' consistent API.
+#' @inheritParams igraph_opt
+#' @keywords internal
+#' @export
+getIgraphOpt <- function(x, default = NULL) {
+  # nocov start
+  lifecycle::deprecate_soft("2.0.0", "getIgraphOpt()", "igraph_opt()")
+
+  if (missing(default)) {
+    get_config(paste0("igraph::", x), .igraph.pars[[x]])
+  } else {
+    get_config(paste0("igraph::", x), default)
+  }
+} # nocov end
 
 #   IGraph R package
 #   Copyright (C) 2005-2012  Gabor Csardi <csardi.gabor@gmail.com>
@@ -43,19 +79,19 @@ igraph.pars.set.verbose <- function(verbose) {
     .Call(R_igraph_set_verbose, verbose)
   } else if (is.character(verbose)) {
     if (!verbose %in% c("tk", "tkconsole")) {
-      stop("Unknown 'verbose' value")
+      cli::cli_abort("Unknown {.arg verbose} value.")
     }
     if (verbose %in% c("tk", "tkconsole")) {
       if (!capabilities()[["X11"]]) {
-        stop("X11 not available")
+        cli::cli_abort("X11 not available.")
       }
       if (!requireNamespace("tcltk", quietly = TRUE)) {
-        stop("tcltk package not available")
+        cli::cli_abort("tcltk package not available.")
       }
     }
     .Call(R_igraph_set_verbose, TRUE)
   } else {
-    stop("'verbose' should be a logical or character scalar")
+    cli::cli_abort("{.arg verbose} should be a logical or character scalar.")
   }
   verbose
 }
@@ -80,53 +116,69 @@ igraph.pars.callbacks <- list("verbose" = igraph.pars.set.verbose)
 #'
 #' The currently used parameters in alphabetical order:
 #' \describe{
-#'   \item{add.params}{Logical scalar, whether to add model
-#'     parameter to the graphs that are created by the various
-#'     graph constructors. By default it is `TRUE`.}
-#'   \item{add.vertex.names}{Logical scalar, whether to add
-#'     vertex names to node level indices, like degree, betweenness
-#'     scores, etc. By default it is `TRUE`.}
-#'   \item{annotate.plot}{Logical scalar, whether to annotate igraph
-#'     plots with the graph's name (`name` graph attribute, if
-#'     present) as `main`, and with the number of vertices and edges
-#'     as `xlab`. Defaults to `FALSE`.}
-#'   \item{dend.plot.type}{The plotting function to use when plotting
-#'     community structure dendrograms via
-#'     [plot_dendrogram()]}. Possible values are \sQuote{auto} (the
-#'     default), \sQuote{phylo}, \sQuote{hclust} and
-#'     \sQuote{dendrogram}. See [plot_dendrogram()] for details.
-#'   \item{edge.attr.comb}{Specifies what to do with the edge
-#'     attributes if the graph is modified. The default value is
-#'     `list(weight="sum", name="concat", "ignore")`. See
-#'     [attribute.combination()] for details on this.}
-#'   \item{print.edge.attributes}{Logical constant, whether to print edge
-#'     attributes when printing graphs. Defaults to `FALSE`.}
-#'   \item{print.full}{Logical scalar, whether [print.igraph()]
-#'     should show the graph structure as well, or only a summary of the
-#'     graph.}
-#'   \item{print.graph.attributes}{Logical constant, whether to print
-#'     graph attributes when printing graphs. Defaults to `FALSE`.}
-#'   \item{print.vertex.attributes}{Logical constant, whether to print
-#'     vertex attributes when printing graphs. Defaults to `FALSE`.}
-#'   \item{return.vs.es}{Whether functions that return a set or sequence
-#'     of vertices/edges should return formal vertex/edge sequence
-#'     objects. This option was introduced in igraph version 1.0.0 and
-#'     defaults to TRUE. If your package requires the old behavior,
-#'     you can set it to FALSE in the `.onLoad` function of
-#'     your package, without affecting other packages.}
-#'   \item{sparsematrices}{Whether to use the `Matrix` package for
-#'     (sparse) matrices. It is recommended, if the user works with
-#'     larger graphs.}
-#'   \item{verbose}{Logical constant, whether igraph functions should
-#'     talk more than minimal. E.g. if `TRUE` then some functions
-#'     will use progress bars while computing. Defaults to `FALSE`.}
-#'   \item{vertex.attr.comb}{Specifies what to do with the vertex
-#'     attributes if the graph is modified. The default value is
-#'     `list(name="concat", "ignore")` See
-#'     [attribute.combination()] for details on this.}
-#' }
+#'     \item{add.params}{
+#'       Logical scalar, whether to add model parameter to the graphs
+#'       that are created by the various graph constructors.
+#'       By default it is `TRUE`.
+#'     }
+#'     \item{add.vertex.names}{
+#'       Logical scalar, whether to add vertex names to node level indices,
+#'       like degree, betweenness scores, etc.
+#'       By default it is `TRUE`.
+#'     }
+#'     \item{annotate.plot}{
+#'       Logical scalar, whether to annotate igraph plots
+#'       with the graph's name (`name` graph attribute, if present) as `main`,
+#'       and with the number of vertices and edges as `xlab`.
+#'       Defaults to `FALSE`.
+#'     }
+#'     \item{dend.plot.type}{
+#'       The plotting function to use when plotting community structure dendrograms via [plot_dendrogram()].
+#'       Possible values are \sQuote{auto} (the default), \sQuote{phylo}, \sQuote{hclust} and \sQuote{dendrogram}.
+#'       See [plot_dendrogram()] for details.
+#'     }
+#'     \item{edge.attr.comb}{
+#'       Specifies what to do with the edge attributes if the graph is modified.
+#'       The default value is `list(weight="sum", name="concat", "ignore")`.
+#'       See [attribute.combination()] for details on this.
+#'     }
+#'     \item{print.edge.attributes}{
+#'       Logical constant, whether to print edge attributes when printing graphs.
+#'       Defaults to `FALSE`.
+#'     }
+#'     \item{print.full}{
+#'       Logical scalar, whether [print.igraph()] should show the graph structure as well,
+#'       or only a summary of the graph.
+#'     }
+#'     \item{print.graph.attributes}{
+#'       Logical constant, whether to print graph attributes when printing graphs. Defaults to `FALSE`.
+#'     }
+#'     \item{print.vertex.attributes}{
+#'       Logical constant, whether to print vertex attributes when printing graphs. Defaults to `FALSE`.
+#'     }
+#'     \item{return.vs.es}{
+#'       Whether functions that return a set or sequence of vertices/edges
+#'       should return formal vertex/edge sequence objects.
+#'       This option was introduced in igraph version 1.0.0 and defaults to TRUE.
+#'       If your package requires the old behavior, you can set it to FALSE in the `.onLoad` function of your package,
+#'       without affecting other packages.
+#'     }
+#'     \item{sparsematrices}{
+#'       Whether to use the `Matrix` package for (sparse) matrices.
+#'       It is recommended, if the user works with larger graphs.
+#'     }
+#'     \item{verbose}{
+#'       Logical constant, whether igraph functions should talk more than minimal.
+#'       E.g. if `TRUE` then some functions will use progress bars while computing. Defaults to `FALSE`.
+#'     }
+#'     \item{vertex.attr.comb}{
+#'       Specifies what to do with the vertex attributes if the graph is modified.
+#'       The default value is `list(name="concat", "ignore")`.
+#'       See [attribute.combination()] for details on this.
+#'     }
+#'   }
 #'
-#' @aliases igraph.options igraph_options getIgraphOpt igraph_opt
+#' @aliases igraph_options igraph_opt
 #' @param \dots A list may be given as the only argument, or any number of
 #'   arguments may be in the `name=value` form, or no argument at all may be
 #'   given. See the Value and Details sections for explanation.
@@ -172,10 +224,11 @@ igraph_i_options <- function(..., .in = parent.frame()) {
   temp <- list(...)
   if (length(temp) == 1 && is.null(names(temp))) {
     arg <- temp[[1]]
-    switch(mode(arg),
+    switch(
+      mode(arg),
       list = temp <- arg,
       character = return(.igraph.pars[arg]),
-      stop("invalid argument: ", sQuote(arg))
+      cli::cli_abort("invalid argument: {arg}.")
     )
   }
   if (length(temp) == 0) {
@@ -184,7 +237,9 @@ igraph_i_options <- function(..., .in = parent.frame()) {
 
   ## Callbacks
   n <- names(temp)
-  if (is.null(n)) stop("options must be given by name")
+  if (is.null(n)) {
+    cli::cli_abort("options must be given by name.")
+  }
   cb <- intersect(names(igraph.pars.callbacks), n)
   for (cn in cb) {
     temp[[cn]] <- igraph.pars.callbacks[[cn]](temp[[cn]])
