@@ -70,6 +70,7 @@
 #'   calculated on `graph.us` and used with multiple graphs. In
 #'   practice, this is currently slower than simply using `graph.them`
 #'   multiple times.
+#' @param weights Numeric vector, edge weights to use for the scan instead of the edge attribute weight. If `NULL` (the default) the edge weight attribute is used.
 #' @param \dots Arguments passed to `FUN`, the function that computes
 #'   the local statistics.
 #' @return For `local_scan()` typically a numeric vector containing the
@@ -102,9 +103,17 @@
 #'   graph.them = pair$graph2,
 #'   neighborhoods = Neigh_1
 #' )
-local_scan <- function(graph.us, graph.them = NULL, k = 1, FUN = NULL,
-                       weighted = FALSE, mode = c("out", "in", "all"),
-                       neighborhoods = NULL, ...) {
+local_scan <- function(
+  graph.us,
+  graph.them = NULL,
+  k = 1,
+  FUN = NULL,
+  weighted = FALSE,
+  mode = c("out", "in", "all"),
+  neighborhoods = NULL,
+  weights = NULL,
+  ...
+) {
   ## Must be igraph object
   stopifnot(is_igraph(graph.us))
 
@@ -118,15 +127,30 @@ local_scan <- function(graph.us, graph.them = NULL, k = 1, FUN = NULL,
   stopifnot(length(k) == 1, k >= 0, trunc(k) == k)
 
   ## Must be NULL or a function
-  stopifnot(is.null(FUN) || is.function(FUN) ||
-    (is.character(FUN) && length(FUN) == 1))
+  stopifnot(
+    is.null(FUN) || is.function(FUN) || (is.character(FUN) && length(FUN) == 1)
+  )
 
   ## Logical scalar
   stopifnot(is.logical(weighted), length(weighted) == 1)
 
   ## If weighted, then the graph(s) must be weighted
-  stopifnot(!weighted || (is_weighted(graph.us) && (is.null(graph.them) ||
-    is_weighted(graph.them))))
+  stopifnot(
+    !weighted ||
+      (is_weighted(graph.us) &&
+        (is.null(graph.them) ||
+          is_weighted(graph.them)))
+  )
+
+  # Check weight parameter only if weighted=TRUE
+  if (weighted && !is.null(weights)) {
+    stopifnot(is.numeric(weights))
+    if (!is.null(graph.them)) {
+      stopifnot(length(weights) == ecount(graph.them))
+    } else {
+      stopifnot(length(weights) == ecount(graph.us))
+    }
+  }
 
   ## Check if 'neighborhoods' makes sense
   if (!is.null(neighborhoods)) {
@@ -134,18 +158,13 @@ local_scan <- function(graph.us, graph.them = NULL, k = 1, FUN = NULL,
     stopifnot(length(neighborhoods) == vcount(graph.us))
   }
   if (!is.null(neighborhoods) && k == 0) {
-    warning("`neighborhoods' ignored for k=0")
+    cli::cli_warn("{.arg neighborhoods} ignored for {.code k=0}.")
     neighborhoods <- NULL
   }
 
   ## Check mode argument
   mode <- igraph.match.arg(mode)
-  cmode <- switch(mode,
-    out = 1,
-    `in` = 2,
-    all = 3,
-    total = 3
-  )
+  cmode <- switch(mode, out = 1, `in` = 2, all = 3, total = 3)
 
   sumweights <- function(g) sum(E(g)$weight)
 
@@ -153,6 +172,19 @@ local_scan <- function(graph.us, graph.them = NULL, k = 1, FUN = NULL,
     FUN <- if (weighted) "sumweights" else "ecount"
   }
 
+  # Only use weights if weighted=TRUE
+  edge_weights <- if (weighted) {
+    if (!is.null(weights)) {
+      as.numeric(weights)
+    } else if (!is.null(graph.them)) {
+      as.numeric(E(graph.them)$weight)
+    } else {
+      as.numeric(E(graph.us)$weight)
+    }
+  } else {
+    NULL
+  }
+
   res <- if (is.null(graph.them)) {
     if (!is.null(neighborhoods)) {
       if (is.character(FUN) && FUN %in% c("ecount", "sumweights")) {
@@ -161,14 +193,16 @@ local_scan <- function(graph.us, graph.them = NULL, k = 1, FUN = NULL,
         })
         on.exit(.Call(R_igraph_finalizer))
         .Call(
-          R_igraph_local_scan_neighborhood_ecount, graph.us,
-          if (weighted) as.numeric(E(graph.us)$weight) else NULL,
+          R_igraph_local_scan_neighborhood_ecount,
+          graph.us,
+          edge_weights,
           neighborhoods
         )
       } else {
         sapply(
           lapply(neighborhoods, induced.subgraph, graph = graph.us),
-          FUN, ...
+          FUN,
+          ...
         )
       }
     } else {
@@ -176,52 +210,63 @@ local_scan <- function(graph.us, graph.them = NULL, k = 1, FUN = NULL,
       if (k == 0) {
         on.exit(.Call(R_igraph_finalizer))
         .Call(
-          R_igraph_local_scan_0, graph.us,
-          if (weighted) as.numeric(E(graph.us)$weight) else NULL, cmode
+          R_igraph_local_scan_0,
+          graph.us,
+          edge_weights,
+          cmode
         )
 
         ## scan-1, ecount
-      } else if (k == 1 && is.character(FUN) &&
-        FUN %in% c("ecount", "sumweights")) {
+      } else if (
+        k == 1 && is.character(FUN) && FUN %in% c("ecount", "sumweights")
+      ) {
         on.exit(.Call(R_igraph_finalizer))
         .Call(
-          R_igraph_local_scan_1_ecount, graph.us,
-          if (weighted) as.numeric(E(graph.us)$weight) else NULL, cmode
+          R_igraph_local_scan_1_ecount,
+          graph.us,
+          edge_weights,
+          cmode
         )
 
         ## scan-k, ecount
       } else if (is.character(FUN) && FUN %in% c("ecount", "sumweights")) {
         on.exit(.Call(R_igraph_finalizer))
         .Call(
-          R_igraph_local_scan_k_ecount, graph.us, as.numeric(k),
-          if (weighted) as.numeric(E(graph.us)$weight) else NULL, cmode
+          R_igraph_local_scan_k_ecount,
+          graph.us,
+          as.numeric(k),
+          edge_weights,
+          cmode
         )
 
         ## General
       } else {
         sapply(
           make_ego_graph(graph.us, order = k, V(graph.us), mode = mode),
-          FUN, ...
+          FUN,
+          ...
         )
       }
     }
   } else {
     if (!is.null(neighborhoods)) {
       neighborhoods <- lapply(neighborhoods, as.vector)
-      if (is.character(FUN) && FUN %in% c("ecount", "wumweights")) {
+      if (is.character(FUN) && FUN %in% c("ecount", "sumweights")) {
         neighborhoods <- lapply(neighborhoods, function(x) {
           as.numeric(x) - 1
         })
         on.exit(.Call(R_igraph_finalizer))
         .Call(
-          R_igraph_local_scan_neighborhood_ecount, graph.them,
-          if (weighted) as.numeric(E(graph.them)$weight) else NULL,
+          R_igraph_local_scan_neighborhood_ecount,
+          graph.them,
+          edge_weights,
           neighborhoods
         )
       } else {
         sapply(
           lapply(neighborhoods, induced.subgraph, graph = graph.them),
-          FUN, ...
+          FUN,
+          ...
         )
       }
     } else {
@@ -229,18 +274,23 @@ local_scan <- function(graph.us, graph.them = NULL, k = 1, FUN = NULL,
       if (k == 0) {
         on.exit(.Call(R_igraph_finalizer))
         .Call(
-          R_igraph_local_scan_0_them, graph.us, graph.them,
-          if (weighted) as.numeric(E(graph.them)$weight) else NULL,
+          R_igraph_local_scan_0_them,
+          graph.us,
+          graph.them,
+          edge_weights,
           cmode
         )
 
         ## scan-1, ecount
-      } else if (k == 1 && is.character(FUN) &&
-        FUN %in% c("ecount", "sumweights")) {
+      } else if (
+        k == 1 && is.character(FUN) && FUN %in% c("ecount", "sumweights")
+      ) {
         on.exit(.Call(R_igraph_finalizer))
         .Call(
-          R_igraph_local_scan_1_ecount_them, graph.us, graph.them,
-          if (weighted) as.numeric(E(graph.them)$weight) else NULL,
+          R_igraph_local_scan_1_ecount_them,
+          graph.us,
+          graph.them,
+          edge_weights,
           cmode
         )
 
@@ -248,20 +298,22 @@ local_scan <- function(graph.us, graph.them = NULL, k = 1, FUN = NULL,
       } else if (is.character(FUN) && FUN %in% c("ecount", "sumweights")) {
         on.exit(.Call(R_igraph_finalizer))
         .Call(
-          R_igraph_local_scan_k_ecount_them, graph.us, graph.them,
+          R_igraph_local_scan_k_ecount_them,
+          graph.us,
+          graph.them,
           as.numeric(k),
-          if (weighted) as.numeric(E(graph.them)$weight) else NULL,
+          edge_weights,
           cmode
         )
 
-        ## general case
+        ## General
       } else {
         sapply(V(graph.us), function(x) {
           vei <- neighborhood(graph.us, order = k, nodes = x, mode = mode)[[1]]
           if (!is.function(FUN)) {
             FUN <- getFunction(FUN, where = environment())
           }
-          FUN(induced.subgraph(graph.them, vei), ...)
+          FUN(induced_subgraph(graph.them, vei), ...)
         })
       }
     }
@@ -298,11 +350,16 @@ local_scan <- function(graph.us, graph.them = NULL, k = 1, FUN = NULL,
 #'   statistics.
 #' @param ... Extra arguments are passed to [local_scan()].
 #' @return A list with entries:
-#'   \item{stat}{The scan statistics in each time step. It is `NA`
-#'     for the initial `tau + ell` time steps.}
-#'   \item{arg_max_v}{The (numeric) vertex ids for the vertex with
-#'     the largest locality statistics, at each time step. It is `NA`
-#'     for the initial `tau + ell` time steps.}
+#'   \describe{
+#'     \item{stat}{
+#'       The scan statistics in each time step.
+#'       It is `NA` for the initial `tau + ell` time steps.
+#'     }
+#'     \item{arg_max_v}{
+#'       The (numeric) vertex ids for the vertex with the largest locality statistics, at each time step.
+#'       It is `NA` for the initial `tau + ell` time steps.
+#'     }
+#'   }
 #'
 #' @family scan statistics
 #' @export
@@ -324,8 +381,13 @@ local_scan <- function(graph.us, graph.them = NULL, k = 1, FUN = NULL,
 #'
 #' scan_stat(graphs = tsg, k = 1, tau = 4, ell = 2)
 #' scan_stat(graphs = tsg, locality = "them", k = 1, tau = 4, ell = 2)
-scan_stat <- function(graphs, tau = 1, ell = 0,
-                      locality = c("us", "them"), ...) {
+scan_stat <- function(
+  graphs,
+  tau = 1,
+  ell = 0,
+  locality = c("us", "them"),
+  ...
+) {
   ## List of igraph graphs, all have same directedness and
   ## weightedness
   stopifnot(
