@@ -1,12 +1,16 @@
 test_that("greedy_vertex_coloring works", {
   g <- make_star(10, mode = "undirected")
-  expect_that(
+  expect_equal(
     greedy_vertex_coloring(g),
-    equals(c(1, rep(2, vcount(g) - 1)))
+    c(1, rep(2, vcount(g) - 1))
   )
-  expect_that(
+  expect_equal(
     greedy_vertex_coloring(g, heuristic = "colored_neighbors"),
-    equals(c(1, rep(2, vcount(g) - 1)))
+    c(1, rep(2, vcount(g) - 1))
+  )
+  expect_equal(
+    greedy_vertex_coloring(g, heuristic = "dsatur"),
+    c(1, rep(2, vcount(g) - 1))
   )
 })
 
@@ -14,8 +18,8 @@ test_that("greedy_vertex_coloring works on named graphs", {
   g <- make_star(10, mode = "undirected")
   V(g)$name <- LETTERS[1:vcount(g)]
   vc <- greedy_vertex_coloring(g)
-  expect_that(as.vector(vc), equals(c(1, rep(2, vcount(g) - 1))))
-  expect_that(names(vc), equals(V(g)$name))
+  expect_equal(as.vector(vc), c(1, rep(2, vcount(g) - 1)))
+  expect_equal(names(vc), V(g)$name)
 })
 
 test_that("simplify_and_colorize works", {
@@ -23,8 +27,8 @@ test_that("simplify_and_colorize works", {
   result <- simplify_and_colorize(g)
 
   expect_true(is_simple(result))
-  expect_that(vcount(result), equals(vcount(g)))
-  expect_that(as_edgelist(result), equals(matrix(c(1:4, 2:5), ncol = 2)))
-  expect_that(V(result)$color, equals(c(0, 0, 0, 0, 1)))
-  expect_that(E(result)$color, equals(c(1, 4, 1, 2)))
+  expect_vcount(result, vcount(g))
+  expect_equal(as_edgelist(result), matrix(c(1:4, 2:5), ncol = 2))
+  expect_equal(V(result)$color, c(0, 0, 0, 0, 1))
+  expect_equal(E(result)$color, c(1, 4, 1, 2))
 })
